aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDmitri Trembovetski <[email protected]>2009-06-17 00:43:02 +0000
committerDmitri Trembovetski <[email protected]>2009-06-17 00:43:02 +0000
commitdf341ba65d01a9562b45c77768efa37cc4733084 (patch)
treea8e8cf1162e8e6f9abbf58d12a67070d79648333
parentdc991d3c36a9b145ca41dd63402adff695e5b5d6 (diff)
Newt: update to the previous fix : need to use 0xFFFF not 0xFF.
git-svn-id: file:///usr/local/projects/SUN/JOGL/git-svn/svn-server-sync/jogl/trunk@1969 232f8b59-042b-4e1e-8c03-345bb8c30851
-rwxr-xr-xsrc/newt/native/WindowsWindow.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/newt/native/WindowsWindow.c b/src/newt/native/WindowsWindow.c
index b86159bb1..908eb2ac0 100755
--- a/src/newt/native/WindowsWindow.c
+++ b/src/newt/native/WindowsWindow.c
@@ -461,24 +461,24 @@ static jchar* GetNullTerminatedStringChars(JNIEnv* env, jstring str)
static jint GetModifiers() {
jint modifiers = 0;
// have to do &0xFF to avoid runtime assert crash caused by compiling with
// /RTCcsu
- if (HIBYTE((GetKeyState(VK_CONTROL) & 0xFF)) != 0) {
+ if (HIBYTE((GetKeyState(VK_CONTROL) & 0xFFFF)) != 0) {
modifiers |= EVENT_CTRL_MASK;
}
- if (HIBYTE((GetKeyState(VK_SHIFT) & 0xFF)) != 0) {
+ if (HIBYTE((GetKeyState(VK_SHIFT) & 0xFFFF)) != 0) {
modifiers |= EVENT_SHIFT_MASK;
}
- if (HIBYTE((GetKeyState(VK_MENU) & 0xFF)) != 0) {
+ if (HIBYTE((GetKeyState(VK_MENU) & 0xFFFF)) != 0) {
modifiers |= EVENT_ALT_MASK;
}
- if (HIBYTE((GetKeyState(VK_LBUTTON) & 0xFF)) != 0) {
+ if (HIBYTE((GetKeyState(VK_LBUTTON) & 0xFFFF)) != 0) {
modifiers |= EVENT_BUTTON1_MASK;
}
- if (HIBYTE((GetKeyState(VK_MBUTTON) & 0xFF)) != 0) {
+ if (HIBYTE((GetKeyState(VK_MBUTTON) & 0xFFFF)) != 0) {
modifiers |= EVENT_BUTTON2_MASK;
}
- if (HIBYTE((GetKeyState(VK_RBUTTON) & 0xFF)) != 0) {
+ if (HIBYTE((GetKeyState(VK_RBUTTON) & 0xFFFF)) != 0) {
modifiers |= EVENT_BUTTON3_MASK;
}
@@ -461,24 +461,24 @@ static jchar* GetNullTerminatedStringChars(JNIEnv* env, jstring str)
static jint GetModifiers() {
jint modifiers = 0;
- // have to do &0xFF to avoid runtime assert crash caused by compiling with
+ // have to do &0xFFFF to avoid runtime assert caused by compiling with
// /RTCcsu